CheckedRem

Trait CheckedRem 

pub trait CheckedRem<Rhs = Self> {
    type Output;

    // Required method
    fn checked_rem(self, rhs: Rhs) -> Self::Output;
}
Checked remainder. Computes self % rhs. Returns None if the result can not be represented by the Output type.

Required Associated Types

type Output

The resulting type after applying checked_rem.

Required Methods

fn checked_rem(self, rhs: Rhs) -> Self::Output

Returns Some(self % rhs) or None if the result can not be represented by the Output type.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl CheckedRem<&Decimal> for &i8

Source

impl CheckedRem<&Decimal> for &i16

Source

impl CheckedRem<&Decimal> for &i32

Source

impl CheckedRem<&Decimal> for &i64

Source

impl CheckedRem<&Decimal> for &i128

Source

impl CheckedRem<&Decimal> for &u8

Source

impl CheckedRem<&Decimal> for &u16

Source

impl CheckedRem<&Decimal> for &u32

Source

impl CheckedRem<&Decimal> for &u64

Source

impl CheckedRem<&Decimal> for i8

Source

impl CheckedRem<&Decimal> for i16

Source

impl CheckedRem<&Decimal> for i32

Source

impl CheckedRem<&Decimal> for i64

Source

impl CheckedRem<&Decimal> for i128

Source

impl CheckedRem<&Decimal> for u8

Source

impl CheckedRem<&Decimal> for u16

Source

impl CheckedRem<&Decimal> for u32

Source

impl CheckedRem<&Decimal> for u64

Source

impl CheckedRem<Decimal> for i8

Source

impl CheckedRem<Decimal> for i16

Source

impl CheckedRem<Decimal> for i32

Source

impl CheckedRem<Decimal> for i64

Source

impl CheckedRem<Decimal> for i128

Source

impl CheckedRem<Decimal> for u8

Source

impl CheckedRem<Decimal> for u16

Source

impl CheckedRem<Decimal> for u32

Source

impl CheckedRem<Decimal> for u64

Source

impl<'a> CheckedRem<Decimal> for &'a i8

Source

impl<'a> CheckedRem<Decimal> for &'a i16

Source

impl<'a> CheckedRem<Decimal> for &'a i32

Source

impl<'a> CheckedRem<Decimal> for &'a i64

Source

impl<'a> CheckedRem<Decimal> for &'a i128

Source

impl<'a> CheckedRem<Decimal> for &'a u8

Source

impl<'a> CheckedRem<Decimal> for &'a u16

Source

impl<'a> CheckedRem<Decimal> for &'a u32

Source

impl<'a> CheckedRem<Decimal> for &'a u64

Implementors

Source

impl CheckedRem for Decimal

Source

impl CheckedRem<&Decimal> for &Decimal

Source

impl CheckedRem<&Decimal> for Decimal

Source

impl CheckedRem<&i8> for &Decimal

Source

impl CheckedRem<&i8> for Decimal

Source

impl CheckedRem<&i16> for &Decimal

Source

impl CheckedRem<&i16> for Decimal

Source

impl CheckedRem<&i32> for &Decimal

Source

impl CheckedRem<&i32> for Decimal

Source

impl CheckedRem<&i64> for &Decimal

Source

impl CheckedRem<&i64> for Decimal

Source

impl CheckedRem<&i128> for &Decimal

Source

impl CheckedRem<&i128> for Decimal

Source

impl CheckedRem<&u8> for &Decimal

Source

impl CheckedRem<&u8> for Decimal

Source

impl CheckedRem<&u16> for &Decimal

Source

impl CheckedRem<&u16> for Decimal

Source

impl CheckedRem<&u32> for &Decimal

Source

impl CheckedRem<&u32> for Decimal

Source

impl CheckedRem<&u64> for &Decimal

Source

impl CheckedRem<&u64> for Decimal

Source

impl CheckedRem<i8> for Decimal

Source

impl CheckedRem<i16> for Decimal

Source

impl CheckedRem<i32> for Decimal

Source

impl CheckedRem<i64> for Decimal

Source

impl CheckedRem<i128> for Decimal

Source

impl CheckedRem<u8> for Decimal

Source

impl CheckedRem<u16> for Decimal

Source

impl CheckedRem<u32> for Decimal

Source

impl CheckedRem<u64> for Decimal

Source

impl<'a> CheckedRem<Decimal> for &'a Decimal

Source

impl<'a> CheckedRem<i8> for &'a Decimal

Source

impl<'a> CheckedRem<i16> for &'a Decimal

Source

impl<'a> CheckedRem<i32> for &'a Decimal

Source

impl<'a> CheckedRem<i64> for &'a Decimal

Source

impl<'a> CheckedRem<i128> for &'a Decimal

Source

impl<'a> CheckedRem<u8> for &'a Decimal

Source

impl<'a> CheckedRem<u16> for &'a Decimal

Source

impl<'a> CheckedRem<u32> for &'a Decimal

Source

impl<'a> CheckedRem<u64> for &'a Decimal